@@ -1,5 +1,5 @@
 function.CB <-
-function(data, marker, status, tag.healthy = 0, direction = c("<", ">"), control = control.cutpoints(), pop.prev, ci.fit = FALSE, conf.level = 0.95, measures.acc = NULL) {
+function(data, marker, status, tag.healthy = 0, direction = c("<", ">"), control = control.cutpoints(), pop.prev, ci.fit = FALSE, conf.level = 0.95, measures.acc) {
 	direction <- match.arg(direction)
 	# The slope of the ROC curve at the optimal cutpoint is computed:
 	S <- ((1-pop.prev)/pop.prev)*control$costs.ratio
